@@ -12,7 +12,7 @@ class PublicSuffixList:
         public_suffix_list = []
 
         dir_path = os.path.dirname(os.path.realpath(__file__))
-        dat_file = f'{dir_path}/../public_suffix_list.dat'
+        dat_file = f'{dir_path}/public_suffix_list.dat'
 
         with open(dat_file, encoding='utf-8') as file:
             data = file.readlines()
